
from machine import UART
import os
from network import LoRa
import socket
import utime
import binascii
import pycom
import ustruct
import machine
import time
from machine import Pin
from onewire import DS18X20
from onewire import OneWire
from machine import ADC
from machine import I2C
from network import Bluetooth

#----------------------------------disable bluetooth and wifi
i2c = I2C()
i2c.deinit()
bluetooth = Bluetooth()
bluetooth.deinit()
pycom.wifi_on_boot(False)

#-----------------------------------------------------------------

#---------------------------------Init DS18B20--------------------
uart = UART(0, baudrate=115200)
os.dupterm(uart)
ow = OneWire(Pin('P10'))
temp = DS18X20(ow)
#-----------------------------------------------------------------

# takes battery voltage readings
def adc_battery():

	adc = ADC(0)                                        # initialise adc hardware
	adc_c = adc.channel(attn=3, pin='P16')              # create an object to sample ADC on pin 16 with attenuation of 11db (config 3)
	adc_samples = []                                    # initialise the list
	for count in range(100):                            # take 100 samples and append them into the list
		adc_samples.append(int(adc_c()))

	adc_samples = sorted(adc_samples)                   # sort the list
	adc_median = adc_samples[int(len(adc_samples)/2)]   # take the center list row value (median average)
	# apply the function to scale to volts
	adc_median = adc_median * 2 / 4095 / 0.3275
	print(adc_samples)

	return adc_median


# Temp measurment
def temp_measure():
    temp.start_conversion()
    time.sleep(1)
    print(temp.read_temp_async())
    te = temp.read_temp_async()
    time.sleep(1)
    return te


# disable LED heartbeat (so we can control the LED)
pycom.heartbeat(False)
# set LED to red
#pycom.rgbled(0x7f0000)

# lora config
lora = LoRa(mode=LoRa.LORAWAN, region=LoRa.EU868)
lora.nvram_restore()
# access info
app_eui = binascii.unhexlify('70B3D57ED00349E9')
app_key = binascii.unhexlify('23458294393180120210380301380138')


# attempt join - continues attempts background
lora.join(activation=LoRa.OTAA, auth=(app_eui, app_key), timeout=0)

# wait for a connection
print('Waiting for LoRaWAN network connection...')
while not lora.has_joined():
	utime.sleep(1)
	# if no connection in a few seconds, then reboot
	if utime.time() > 15:
		print("possible timeout")
		machine.reset()
	pass

# we're online, set LED to green and notify via print
#pycom.rgbled(0x004600)
print('Network joined!')

# setup the socket
s = socket.socket(socket.AF_LORA, socket.SOCK_RAW)
s.setsockopt(socket.SOL_LORA, socket.SO_DR, 5)
s.setblocking(False)
s.bind(1)

lipo_voltage = adc_battery()
print("Battery voltage:  ", lipo_voltage)
#packet = ustruct.pack('f',lipo_voltage)
#s.send(packet)# send the prepared packet via LoRa

tem = temp_measure()
packet = ustruct.pack('f', tem) + ustruct.pack('f',lipo_voltage)# could be extended like this struct.pack('f', temp) + struct.pack('c',"example text")
s.send(packet)# send the prepared packet via LoRa

utime.sleep(10)

lora.nvram_save()
#s.close()
machine.deepsleep(1800000) #sleep 30 min.
#machine.reset()
